@@ -1,5 +1,5 @@
 use bitcoind::bitcoincore_rpc::Client;
-use bitcoind::BitcoinD;
+use bitcoind::{BitcoinD, ConnectParams};
 use std::ffi::OsStr;
 use std::fmt;
 
@@ -11,7 +11,7 @@ mod versions;
 pub struct ElementsD(BitcoinD);
 
 #[non_exhaustive]
-pub struct Conf<'a>(bitcoind::Conf<'a>);
+pub struct Conf<'a>(pub bitcoind::Conf<'a>);
 
 /// All the possible error in this crate
 pub enum Error {
@@ -99,6 +99,10 @@ impl ElementsD {
     pub fn client(&self) -> &Client {
         &self.0.client
     }
+
+    pub fn params(&self) -> &ConnectParams {
+        &self.0.params
+    }
 }
 
 /// Returns the daemons executable path, if it's provided as a feature or as `ELEMENTSD_EXE` env var
