@@ -1,12 +1,6 @@
-pub const HAS_FEATURE: bool = cfg!(any(
-    feature = "0_21_0",
-    feature = "0_18_1_12",
-));
+pub const HAS_FEATURE: bool = cfg!(any(feature = "0_21_0", feature = "0_18_1_12",));
 
-#[cfg(not(any(
-feature = "0_21_0",
-feature = "0_18_1_12",
-)))]
+#[cfg(not(any(feature = "0_21_0", feature = "0_18_1_12",)))]
 pub const VERSION: &str = "N/A";
 
 #[cfg(feature = "0_21_0")]
